#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Mar  2 14:29:24 2021

@author: eduard
"""

def print_HALLO():
    print("Hello from print me now")
    
def print_HALLO_2():
    print("Hello from print me now 2")    